==> ejc-lz-impl-3.0.0-20220302.022755-3-sources.jar: com/ejianc/business/base/bean/ProductEntity.java <==
package com.ejianc.business.base.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产品
 * 
 * @author generator
 * 
 */
 @TableName("ejc_base_product")
public class ProductEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="name")
    private String name; // 运输商名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="operator_id")
    private String operatorId; // 经办人id
    @TableField(value="operator_name")
    private String operatorName; // 经办人名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private Long changeId; // 变更单据id
    @TableField(value="change_state")
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="category_id")
    private Long categoryId; // 产品类别主键
    @TableField(value="spec_id")
    private Long specId; // 产品规格主键
    @TableField(value="grade_id")
    private Long gradeId; // 产品级配主键
    @TableField(value="alias")
    private String alias; // 产品别名
    @TableField(value="bloc_standard")
    private Integer blocStandard; // 集团标准
    @TableField(value="stone_id")
    private Long stoneId; // 石料主键
    @TableField(value="asphalt_id")
    private Long asphaltId; // 沥青主键
    @TableField(value="bloc_product_id")
    private Long blocProductId; // 集团产品主键
    @TableField(value="cDefine1")
    private String cdefine1; // 
    @TableField(value="cDefine2")
    private String cdefine2; // 
    @TableField(value="cDefine3")
    private String cdefine3; // 
    @TableField(value="cDefine4")
    private String cdefine4; // 
    @TableField(value="cDefine5")
    private String cdefine5; // 
    @TableField(value="cDefine6")
    private String cdefine6; // 
    @TableField(value="cDefine7")
    private String cdefine7; // 
    @TableField(value="cDefine8")
    private String cdefine8; // 
    @TableField(value="cDefine9")
    private String cdefine9; // 
    @TableField(value="cDefine10")
    private String cdefine10; // 
    @TableField(value="cDefine11")
    private Integer cdefine11; // 
    @TableField(value="cDefine12")
    private Integer cdefine12; // 
    @TableField(value="cDefine13")
    private BigDecimal cdefine13; // 
    @TableField(value="cDefine14")
    private BigDecimal cdefine14; // 
    @TableField(value="cDefine15")
    private Date cdefine15; // 
    @TableField(value="cDefine16")
    private Date cdefine16; // 
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public String getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(String operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public Long getSpecId() {
        return specId;
    }

    public void setSpecId(Long specId) {
        this.specId = specId;
    }
    public Long getGradeId() {
        return gradeId;
    }

    public void setGradeId(Long gradeId) {
        this.gradeId = gradeId;
    }
    public String getAlias() {
        return alias;
    }

    public void setAlias(String alias) {
        this.alias = alias;
    }
    public Integer getBlocStandard() {
        return blocStandard;
    }

    public void setBlocStandard(Integer blocStandard) {
        this.blocStandard = blocStandard;
    }
    public Long getStoneId() {
        return stoneId;
    }

    public void setStoneId(Long stoneId) {
        this.stoneId = stoneId;
    }
    public Long getAsphaltId() {
        return asphaltId;
    }

    public void setAsphaltId(Long asphaltId) {
        this.asphaltId = asphaltId;
    }
    public Long getBlocProductId() {
        return blocProductId;
    }

    public void setBlocProductId(Long blocProductId) {
        this.blocProductId = blocProductId;
    }
    public String getCdefine1() {
        return cdefine1;
    }

    public void setCdefine1(String cdefine1) {
        this.cdefine1 = cdefine1;
    }
    public String getCdefine2() {
        return cdefine2;
    }

    public void setCdefine2(String cdefine2) {
        this.cdefine2 = cdefine2;
    }
    public String getCdefine3() {
        return cdefine3;
    }

    public void setCdefine3(String cdefine3) {
        this.cdefine3 = cdefine3;
    }
    public String getCdefine4() {
        return cdefine4;
    }

    public void setCdefine4(String cdefine4) {
        this.cdefine4 = cdefine4;
    }
    public String getCdefine5() {
        return cdefine5;
    }

    public void setCdefine5(String cdefine5) {
        this.cdefine5 = cdefine5;
    }
    public String getCdefine6() {
        return cdefine6;
    }

    public void setCdefine6(String cdefine6) {
        this.cdefine6 = cdefine6;
    }
    public String getCdefine7() {
        return cdefine7;
    }

    public void setCdefine7(String cdefine7) {
        this.cdefine7 = cdefine7;
    }
    public String getCdefine8() {
        return cdefine8;
    }

    public void setCdefine8(String cdefine8) {
        this.cdefine8 = cdefine8;
    }
    public String getCdefine9() {
        return cdefine9;
    }

    public void setCdefine9(String cdefine9) {
        this.cdefine9 = cdefine9;
    }
    public String getCdefine10() {
        return cdefine10;
    }

    public void setCdefine10(String cdefine10) {
        this.cdefine10 = cdefine10;
    }
    public Integer getCdefine11() {
        return cdefine11;
    }

    public void setCdefine11(Integer cdefine11) {
        this.cdefine11 = cdefine11;
    }
    public Integer getCdefine12() {
        return cdefine12;
    }

    public void setCdefine12(Integer cdefine12) {
        this.cdefine12 = cdefine12;
    }
    public BigDecimal getCdefine13() {
        return cdefine13;
    }

    public void setCdefine13(BigDecimal cdefine13) {
        this.cdefine13 = cdefine13;
    }
    public BigDecimal getCdefine14() {
        return cdefine14;
    }

    public void setCdefine14(BigDecimal cdefine14) {
        this.cdefine14 = cdefine14;
    }
    public Date getCdefine15() {
        return cdefine15;
    }

    public void setCdefine15(Date cdefine15) {
        this.cdefine15 = cdefine15;
    }
    public Date getCdefine16() {
        return cdefine16;
    }

    public void setCdefine16(Date cdefine16) {
        this.cdefine16 = cdefine16;
    }
    
}

==> ejc-lz-impl-3.0.0-20220309.065506-10-sources.jar: com/ejianc/business/base/bean/ProductEntity.java <==
package com.ejianc.business.base.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产品
 * 
 * @author generator
 * 
 */
 @TableName("ejc_base_product")
public class ProductEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="name")
    private String name; // 运输商名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="operator_id")
    private String operatorId; // 经办人id
    @TableField(value="operator_name")
    private String operatorName; // 经办人名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private Long changeId; // 变更单据id
    @TableField(value="change_state")
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="category_id")
    private Long categoryId; // 产品类别主键
    @TableField(value="spec_id")
    private Long specId; // 产品规格主键
    @TableField(value="grade_id")
    private Long gradeId; // 产品级配主键
    @TableField(value="alias")
    private String alias; // 产品别名
    @TableField(value="bloc_standard")
    private Integer blocStandard; // 集团标准
    @TableField(value="stone_id")
    private Long stoneId; // 石料主键
    @TableField(value="asphalt_id")
    private Long asphaltId; // 沥青主键
    @TableField(value="bloc_product_id")
    private Long blocProductId; // 集团产品主键
    @TableField(value="cDefine1")
    private String cdefine1; // 
    @TableField(value="cDefine2")
    private String cdefine2; // 
    @TableField(value="cDefine3")
    private String cdefine3; // 
    @TableField(value="cDefine4")
    private String cdefine4; // 
    @TableField(value="cDefine5")
    private String cdefine5; // 
    @TableField(value="cDefine6")
    private String cdefine6; // 
    @TableField(value="cDefine7")
    private String cdefine7; // 
    @TableField(value="cDefine8")
    private String cdefine8; // 
    @TableField(value="cDefine9")
    private String cdefine9; // 
    @TableField(value="cDefine10")
    private String cdefine10; // 
    @TableField(value="cDefine11")
    private Integer cdefine11; // 
    @TableField(value="cDefine12")
    private Integer cdefine12; // 
    @TableField(value="cDefine13")
    private BigDecimal cdefine13; // 
    @TableField(value="cDefine14")
    private BigDecimal cdefine14; // 
    @TableField(value="cDefine15")
    private Date cdefine15; // 
    @TableField(value="cDefine16")
    private Date cdefine16; // 
    @TableField(value="spec_name")
    private String specName; // 产品规格名称
    @TableField(value="category_name")
    private String categoryName; // 产品类别名称
    @TableField(value="grade_name")
    private String gradeName; // 产品级配名称
    @TableField(value="stone_name")
    private String stoneName; // 石料名称
    @TableField(value="asphalt_name")
    private String asphaltName; // 沥青名称
    @TableField(value="bloc_product_name")
    private String blocProductName; // 集团产品名称
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public String getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(String operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public Long getSpecId() {
        return specId;
    }

    public void setSpecId(Long specId) {
        this.specId = specId;
    }
    public Long getGradeId() {
        return gradeId;
    }

    public void setGradeId(Long gradeId) {
        this.gradeId = gradeId;
    }
    public String getAlias() {
        return alias;
    }

    public void setAlias(String alias) {
        this.alias = alias;
    }
    public Integer getBlocStandard() {
        return blocStandard;
    }

    public void setBlocStandard(Integer blocStandard) {
        this.blocStandard = blocStandard;
    }
    public Long getStoneId() {
        return stoneId;
    }

    public void setStoneId(Long stoneId) {
        this.stoneId = stoneId;
    }
    public Long getAsphaltId() {
        return asphaltId;
    }

    public void setAsphaltId(Long asphaltId) {
        this.asphaltId = asphaltId;
    }
    public Long getBlocProductId() {
        return blocProductId;
    }

    public void setBlocProductId(Long blocProductId) {
        this.blocProductId = blocProductId;
    }
    public String getCdefine1() {
        return cdefine1;
    }

    public void setCdefine1(String cdefine1) {
        this.cdefine1 = cdefine1;
    }
    public String getCdefine2() {
        return cdefine2;
    }

    public void setCdefine2(String cdefine2) {
        this.cdefine2 = cdefine2;
    }
    public String getCdefine3() {
        return cdefine3;
    }

    public void setCdefine3(String cdefine3) {
        this.cdefine3 = cdefine3;
    }
    public String getCdefine4() {
        return cdefine4;
    }

    public void setCdefine4(String cdefine4) {
        this.cdefine4 = cdefine4;
    }
    public String getCdefine5() {
        return cdefine5;
    }

    public void setCdefine5(String cdefine5) {
        this.cdefine5 = cdefine5;
    }
    public String getCdefine6() {
        return cdefine6;
    }

    public void setCdefine6(String cdefine6) {
        this.cdefine6 = cdefine6;
    }
    public String getCdefine7() {
        return cdefine7;
    }

    public void setCdefine7(String cdefine7) {
        this.cdefine7 = cdefine7;
    }
    public String getCdefine8() {
        return cdefine8;
    }

    public void setCdefine8(String cdefine8) {
        this.cdefine8 = cdefine8;
    }
    public String getCdefine9() {
        return cdefine9;
    }

    public void setCdefine9(String cdefine9) {
        this.cdefine9 = cdefine9;
    }
    public String getCdefine10() {
        return cdefine10;
    }

    public void setCdefine10(String cdefine10) {
        this.cdefine10 = cdefine10;
    }
    public Integer getCdefine11() {
        return cdefine11;
    }

    public void setCdefine11(Integer cdefine11) {
        this.cdefine11 = cdefine11;
    }
    public Integer getCdefine12() {
        return cdefine12;
    }

    public void setCdefine12(Integer cdefine12) {
        this.cdefine12 = cdefine12;
    }
    public BigDecimal getCdefine13() {
        return cdefine13;
    }

    public void setCdefine13(BigDecimal cdefine13) {
        this.cdefine13 = cdefine13;
    }
    public BigDecimal getCdefine14() {
        return cdefine14;
    }

    public void setCdefine14(BigDecimal cdefine14) {
        this.cdefine14 = cdefine14;
    }
    public Date getCdefine15() {
        return cdefine15;
    }

    public void setCdefine15(Date cdefine15) {
        this.cdefine15 = cdefine15;
    }
    public Date getCdefine16() {
        return cdefine16;
    }

    public void setCdefine16(Date cdefine16) {
        this.cdefine16 = cdefine16;
    }
    public String getSpecName() {
        return specName;
    }

    public void setSpecName(String specName) {
        this.specName = specName;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public String getGradeName() {
        return gradeName;
    }

    public void setGradeName(String gradeName) {
        this.gradeName = gradeName;
    }
    public String getStoneName() {
        return stoneName;
    }

    public void setStoneName(String stoneName) {
        this.stoneName = stoneName;
    }
    public String getAsphaltName() {
        return asphaltName;
    }

    public void setAsphaltName(String asphaltName) {
        this.asphaltName = asphaltName;
    }
    public String getBlocProductName() {
        return blocProductName;
    }

    public void setBlocProductName(String blocProductName) {
        this.blocProductName = blocProductName;
    }
    
}
